# Table of Contents

- [tech-category-modeling-v3](<./tech-category-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Tech Category (Meta Model v3)](<./Modeling-Tech-Category-Meta-Model-v3.md>)
  - [Overview](<./Modeling-Tech-Category-Meta-Model-v3/Overview.md>)
  - [Resources](<./Modeling-Tech-Category-Meta-Model-v3/Resources.md>)
